Documentation
¶
Index ¶
Constants ¶
const ( Trace = iota Debug Info Warning Error Fatal )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// LogLevel is the level filter for the log output
LogLevel int
// OutputFields is a list of fields to include on the log output
OutputFields []string
// ExcludeFields is a list of fields to exclude from the log output
ExcludeFields []string
// Filter is a map of fields and values which are used to filter the log output
Filter map[string]string
// NoTime disables the time output
NoTime bool
// Keep lines with no fields
KeepEmpty bool
// Only values
Raw bool
// All after output in record order (causes output to become order)
All bool
// How long can a line be?
BufferSize int
}
Click to show internal directories.
Click to hide internal directories.